@@ -369,7 +369,7 @@ class HttpAsyncHook(BaseHook):
                     url,
                     json=data if self.method in ("POST", "PATCH") else None,
                     params=data if self.method == "GET" else None,
-                    headers=headers,
+                    headers=_headers,
                     auth=auth,
                     **extra_options,
                 )
